<?php

/**
 * Manage meta boxes
 *
 * Register meta boxes to manage Photoslurp widget settings
 *
 * @package    Photoslurp
 * @subpackage Photoslurp/admin
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Admin_Meta_Boxes {

	/**
	 * Meta boxes
	 *
	 * @var array
	 */
	public static $meta_boxes = array();

	/**
	 * Constructor
	 *
	 * Add meta boxes
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		$this->add_meta_boxes();
	}

	/**
	 * Add meta boxes
	 *
	 * @since    1.0.0
	 */
	public function add_meta_boxes() {
		/**
		 * Photoslurp widget settings meta box
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/meta-boxes/class-photoslurp-meta-box-widget-settings.php';

		self::$meta_boxes[] = new Photoslurp_Meta_Box_Widget_Settings();

		/**
		 * Photoslurp widget placement meta box
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/meta-boxes/class-photoslurp-meta-box-widget-placement.php';

		self::$meta_boxes[] = new Photoslurp_Meta_Box_Widget_Placement();
	}

	/**
	 * Save meta box
	 *
	 * Performs general checks before saving meta box data.
	 * May be used by all meta boxes.
	 *
	 * @since    1.0.0
	 *
	 * @param    int $post_id
	 * @param    WP_Post $post
	 *
	 * @return   boolean
	 */
	public static function save( $post_id, $post ) {
		// $post_id and $post are required
		if ( empty( $post_id ) || empty( $post ) ) {
			return false;
		}

		// Dont' save meta boxes for revisions or autosaves
		if ( defined( 'DOING_AUTOSAVE' ) || is_int( wp_is_post_revision( $post ) ) || is_int( wp_is_post_autosave( $post ) ) ) {
			return false;
		}

		// Check the post being saved == the $post_id to prevent triggering this call for other save_post events
		if ( empty( $_POST['post_ID'] ) || $_POST['post_ID'] != $post_id ) {
			return false;
		}

		// Check user has permission to edit
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return false;
		}

		return true;
	}

}
