(function ($) {
    'use strict';

    var tabs = {
        selectors: {
            tab: '.photoslurp-tab',
            tab_content: '.photoslurp-tab-content'
        },
        classes: {
            tab_active: 'photoslurp-tab-active',
            tab_content_active: 'photoslurp-tab-content-active'
        },
        init: function () {
            if ( $( tabs.selectors.tab ).length ) {

                $( tabs.selectors.tab + ':first-child' ).addClass( tabs.classes.tab_active );
                $( tabs.selectors.tab_content + ':first-child' ).addClass( tabs.classes.tab_content_active );

                tabs.clicks();
            }
        },
        clicks: function () {
            $( tabs.selectors.tab ).on( 'click', function( e ) {
                e.preventDefault();

                var tab = $( this ).data( 'tab' );

                $( tabs.selectors.tab ).removeClass( tabs.classes.tab_active );
                $( this ).addClass( tabs.classes.tab_active );

                $( tabs.selectors.tab_content ).removeClass( tabs.classes.tab_content_active );
                $( tabs.selectors.tab_content + '[data-tab=' + tab + ']' ).addClass( tabs.classes.tab_content_active );
            } );
        }
    };

    var forms = {
        selectors: {
            form: '.photoslurp-form',
            show_when: '[data-show-when-field^=photoslurp]'
        },
        init: function () {
            forms.show_fields();
            forms.changes();
        },
        changes: function () {
            $( 'input, select', forms.selectors.form ).on( 'change', function() {
                forms.show_fields();
            } );
        },
        show_fields: function () {
            $( forms.selectors.show_when ).each( function() {
                var name = $( this ).data( 'show-when-field' ),
                    value = $( this ).data( 'show-when-field-value' ),
                    auto_reset = $( this ).data( 'auto-reset' ),
                    target = $( '[name=' + name + ']' ),
                    values = value.toString().split( ',' );

                if ( target.length ) {
                    for ( var i in values ) {
                        if ( values.hasOwnProperty(i) ) {
                            if ( values[ i ] === 'not_empty' && target.val().length ) {
                                $( this ).show();
                                return;
                            } else if ( values[ i ].toString() === target.val().toString() ) {
                                $( this ).show();
                                return;
                            } else {
                                // Some field should have their value reset when they get hidden
                                if ( typeof auto_reset !== 'undefined' ) {
                                    var select = $( this ).find( 'select' );
                                    if ( select.length ) {
                                        select.val( $( 'option:first', select ).val() );
                                    }
                                }
                                $( this ).hide();
                            }
                        }
                    }
                }
            } );
        }
    };

    $(function () {
        tabs.init();
        forms.init();
    });

})(jQuery);
