<?php

/**
 * File helper
 *
 * Provides functionality for uploading files to the
 * WordPress uploads folder
 *
 * @since      1.0.0
 * @package    Photoslurp
 * @subpackage Photoslurp/includes
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_File_Helper {

	/**
	 * Returns the base upload path for this plugin
	 * Creates the folder if it does nog exist
	 *
	 * @since    1.0.0
	 */
	public static function get_plugin_upload_path() {
		$upload_dir = wp_upload_dir( null, false );
		$base_path  = trailingslashit( $upload_dir['basedir'] );

		if ( ! file_exists( $base_path . 'photoslurp' ) ) {
			mkdir( $base_path . 'photoslurp' );
		}

		return $base_path . 'photoslurp';
	}

	/**
	 * Returns the base upload url for this plugin
	 *
	 * @since    1.0.0
	 */
	public static function get_plugin_upload_url() {
		$upload_dir = wp_upload_dir( null, false );
		$base_path  = trailingslashit( $upload_dir['baseurl'] );

		return $base_path . 'photoslurp';
	}

	/**
	 * Check if given file exists
	 *
	 * @since    1.0.0
	 *
	 * @param    string $file
	 *
	 * @return   bool
	 */
	public static function file_exists( $file ) {
		$upload_dir = self::get_plugin_upload_path();

		if ( ! file_exists( $upload_dir . '/' . $file ) ) {
			return false;
		}

		return true;
	}

}