<?php

/**
 * Register post types
 *
 * @since      1.0.0
 * @package    Photoslurp
 * @subpackage Photoslurp/includes
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Post_Types {

	/**
	 * Register required actions
	 */
	public static function init() {
		add_action( 'init', array( __CLASS__, 'register_post_types' ), 5 );
	}

	/**
	 * Register post types
	 */
	public static function register_post_types() {
		if ( ! is_blog_installed() || post_type_exists( 'photoslurp_widget' ) ) {
			return;
		}

		$args = array(
			'labels'              => array(
				'name'                  => __( 'Photoslurp widgets', 'photoslurp' ),
				'singular_name'         => __( 'Photoslurp widget', 'photoslurp' ),
				'menu_name'             => _x( 'Widgets', 'Admin menu name', 'photoslurp' ),
				'add_new'               => __( 'Add Photoslurp widget', 'photoslurp' ),
				'add_new_item'          => __( 'Add new Photoslurp widget', 'photoslurp' ),
				'edit'                  => __( 'Edit', 'photoslurp' ),
				'edit_item'             => __( 'Edit Photoslurp widget', 'photoslurp' ),
				'new_item'              => __( 'New Photoslurp widget', 'photoslurp' ),
				'view'                  => __( 'View Photoslurp widget', 'photoslurp' ),
				'view_item'             => __( 'View Photoslurp widget', 'photoslurp' ),
				'search_items'          => __( 'Search Photoslurp widgets', 'photoslurp' ),
				'not_found'             => __( 'No Photoslurp widgets found', 'photoslurp' ),
				'not_found_in_trash'    => __( 'No Photoslurp widgets found in trash', 'photoslurp' ),
				'parent'                => __( 'Parent Photoslurp widget', 'photoslurp' ),
				'featured_image'        => __( 'Photoslurp widget image', 'photoslurp' ),
				'set_featured_image'    => __( 'Set Photoslurp widget image', 'photoslurp' ),
				'remove_featured_image' => __( 'Remove Photoslurp widget image', 'photoslurp' ),
				'use_featured_image'    => __( 'Use as Photoslurp widget image', 'photoslurp' ),
				'insert_into_item'      => __( 'Insert into Photoslurp widget', 'photoslurp' ),
				'uploaded_to_this_item' => __( 'Uploaded to this Photoslurp widget', 'photoslurp' ),
				'filter_items_list'     => __( 'Filter Photoslurp widgets', 'photoslurp' ),
				'items_list_navigation' => __( 'Photoslurp widgets navigation', 'photoslurp' ),
				'items_list'            => __( 'Photoslurp widgets list', 'photoslurp' ),
			),
			'description'         => __( 'This is where you can add new photoslurp widgets.', 'photoslurp' ),
			'public'              => false,
			'show_ui'             => true,
			'show_in_menu'        => 'photoslurp',
			'publicly_queryable'  => true,
			'exclude_from_search' => true,
			'hierarchical'        => false,
			'query_var'           => true,
			'supports'            => array( 'title' ),
			'has_archive'         => false,
			'show_in_nav_menus'   => true,
			'show_in_rest'        => false,
		);

		register_post_type( 'photoslurp_widget', $args );
	}

}

Photoslurp_Post_Types::init();