<?php

/**
 * Widget settings
 *
 * Defines widget settings
 *
 * @since      1.0.0
 * @package    Photoslurp
 * @subpackage Photoslurp/includes
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Settings_Widget {

	/**
	 * Get settings
	 *
	 * @since    1.0.0
	 * @return   array
	 */
	public static function get() {

		$settings = array(

			// Configuration
			array(
				'id'          => 'photoslurp_user_name',
				'label'       => __( 'User name', 'photoslurp' ),
				'description' => __( 'Your Photoslurp user name', 'photoslurp' ),
				'required'    => true,
				'type'        => 'text',
				'section'     => 'configuration'
			),

			array(
				'id'          => 'photoslurp_widget_id',
				'label'       => __( 'Widget ID', 'photoslurp' ),
				'description' => __( 'A unique identifier for each of the widgets you use on your website', 'photoslurp' ),
				'required'    => true,
				'type'        => 'text',
				'section'     => 'configuration'
			),

			array(
				'id'          => 'photoslurp_page_type',
				'label'       => __( 'Page type', 'photoslurp' ),
				'description' => __( 'This parameter is used in analytics calculations', 'photoslurp' ),
				'type'        => 'select',
				'options'     => array(
					'home'     => 'home',
					'product'  => 'product',
                    'category' => 'category',
					'lookbook' => 'lookbook'
				),
				'section'     => 'configuration'
			),

            // Display on product page

            array(
                'id'          => 'photoslurp_show_on_product_page',
                'label'       => __( 'Show on product pages', 'photoslurp' ),
                'description' => __( 'Show this widget on product pages.', 'photoslurp' ),
                'type'        => 'select',
                'options'     => array(
                    '0' => 'No',
                    '1' => 'Yes'
                ),
                'auto_reset'  => true,
                'show_when'   => array( 'photoslurp_page_type' => 'product' ),
                'section'     => 'configuration'
            ),

            array(
                'id'          => 'photoslurp_product_page_hook',
                'label'       => __( 'Product page position', 'photoslurp' ),
                'description' => __( 'Where on the product page to show this widget.', 'photoslurp' ),
                'type'        => 'select',
                'show_when'   => array( 'photoslurp_show_on_product_page' => '1' ),
                'options'     => array(
                    '' => __( 'After product (default)', 'photoslurp' ),
                    'woocommerce_before_single_product' => __( 'Before product', 'photoslurp' ),
                    'woocommerce_after_single_product_summary' => __( 'After product summary', 'photoslurp' ),
                    'custom' => __( 'Use custom hook', 'photoslurp' )
                ),
                'section'     => 'configuration'
            ),

            array(
                'id'          => 'photoslurp_product_page_hook_custom',
                'label'       => __( 'Product page custom hook', 'photoslurp' ),
                'description' => __( 'Show widget on product page at custom hook name', 'photoslurp' ),
                'type'        => 'text',
                'show_when'   => array( 'photoslurp_product_page_hook' => 'custom' ),
                'section'     => 'configuration'
            ),

            // Display on category page

            array(
                'id'          => 'photoslurp_show_on_category_page',
                'label'       => __( 'Show on category pages', 'photoslurp' ),
                'description' => __( 'Show this widget on category pages.', 'photoslurp' ),
                'type'        => 'select',
                'options'     => array(
                    '0' => 'No',
                    '1' => 'Yes',
                    '2' => 'Only for selected categories'
                ),
                'auto_reset'  => true,
                'show_when'   => array( 'photoslurp_page_type' => 'category' ),
                'section'     => 'configuration'
            ),

            array(
                'id'          => 'photoslurp_category_pages_to_show_on',
                'label'       => __( 'Selected categories', 'photoslurp' ),
                'description' => __( 'Select the categories where to show the widget. To select multiple categories hold down the Ctrl-key on Windows or the Command-key on Mac while clicking on the category names. To select a range: Click the first category, then hold down the Shift-key and then click the last category in the range.', 'photoslurp' ),
                'type'        => 'select',
                'multiple'    => true,
                'options'     => Photoslurp_Product_Helper::get_categories_for_select(),
                'section'     => 'configuration',
                'show_when'   => array( 'photoslurp_show_on_category_page' => '2' )
            ),

            array(
                'id'          => 'photoslurp_category_page_hook',
                'label'       => __( 'Category page position', 'photoslurp' ),
                'description' => __( 'Where on the category page to show this widget.', 'photoslurp' ),
                'type'        => 'select',
                'show_when'   => array( 'photoslurp_show_on_category_page' => '1' ),
                'options'     => array(
                    'woocommerce_after_shop_loop' => __( 'After products (default)', 'photoslurp' ),
                    'woocommerce_archive_description' => __( 'After description', 'photoslurp' ),
                    'custom' => __( 'Use custom hook', 'photoslurp' )
                ),
                'section'     => 'configuration'
            ),

            array(
                'id'          => 'photoslurp_category_page_hook_custom',
                'label'       => __( 'Category page custom hook', 'photoslurp' ),
                'description' => __( 'Show widget on category page at custom hook name', 'photoslurp' ),
                'type'        => 'text',
                'show_when'   => array( 'photoslurp_category_page_hook' => 'custom' ),
                'section'     => 'configuration'
            ),

            // Product types

            array(
                'id'          => 'photoslurp_automatic_product_types',
                'label'       => __( 'Only show media from product category (automatic)', 'photoslurp' ),
                'description' => __( 'When no media is available for a specific product, show only photos related to products in the same product category.', 'photoslurp' ),
                'type'        => 'select',
                'options'     => array(
                    ''  => '',
                    '0' => 'No',
                    '1' => 'Yes'
                ),
                'section'     => 'configuration',
                'show_when'   => array( 'photoslurp_page_type' => 'product,category' )
            ),

            array(
                'id'          => 'photoslurp_custom_product_types',
                'label'       => __( 'Only show media from product categories', 'photoslurp' ),
                'description' => __( 'Show photos related to products in given product categories. To select multiple categories hold down the Ctrl-key on Windows or the Command-key on Mac while clicking on the category names. To select a range: Click the first category, then hold down the Shift-key and then click the last category in the range.', 'photoslurp' ),
                'type'        => 'select',
                'multiple'    => true,
                'options'     => Photoslurp_Product_Helper::get_categories_for_select(),
                'section'     => 'configuration',
                'show_when'   => array( 'photoslurp_page_type' => 'lookbook' )
            ),

			// Language

            array(
                'id'          => 'photoslurp_language',
                'label'       => __( 'Language', 'photoslurp' ),
                'description' => __( 'Example: en_US. Locale code to set the language. All hardcoded text will be translated automatically. When left empty, the current WordPress language will be used.', 'photoslurp' ),
                'type'        => 'text',
                'section'     => 'configuration',
                'show_when'   => array( 'option' => array( 'photoslurp_field_enable_lang_parameter' => '1' ) )
            ),

            // Custom CSS

			array(
				'id'          => 'photoslurp_custom_css',
				'label'       => __( 'Custom CSS', 'photoslurp' ),
				'description' => __( 'Enter your custom CSS code here. Only requires dot notation with !important flag. Eg: .galleria-info-product-description { margin-top:50px !important }', 'photoslurp' ),
				'type'        => 'textarea',
				'section'     => 'custom_css'
			),

		);

		return $settings;
	}

	/**
	 * Get sections
	 *
	 * @since    1.0.0
	 * @return   array
	 */
	public static function get_sections() {

		$sections = array(

			array(
				'id'    => 'configuration',
				'label' => __( 'Configuration', 'photoslurp' )
			),

			array(
				'id'    => 'custom_css',
				'label' => __( 'Custom CSS', 'photoslurp' )
			),

		);

		return $sections;
	}

}
