<?php

/**
 * Cron
 *
 * Manage scheduled events
 *
 * @package    Photoslurp
 * @subpackage Photoslurp/public
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Public_Cron {

	/**
	 * Initialize the class
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		$this->schedule();
	}

	/**
	 * Schedule events
	 *
	 * @since    1.0.0
	 */
	public function schedule() {
		$events = $this->get_events();

		foreach ( $events as $event ) {
			/**
			 * Add an action for when the scheduled event hook is triggered
			 */
			add_action( $event['hook'], array( $this, 'execute' ) );

			/**
			 * Pass the hook name
			 */
			$arguments = array(
				'hook' => $event['hook']
			);

			/**
			 * Schedule the event if it is nog scheduled yet
			 */
			if ( ! wp_next_scheduled( $event['hook'], $arguments ) ) {
				wp_schedule_event( time(), $event['recurrence'], $event['hook'], $arguments );
			}
		}

	}

	/**
	 * Get events to be scheduled
	 *
	 * @since    1.0.0
	 */
	public function get_events() {
	    $events = array(
	        array(
                'hook'       => 'photoslurp_generate_products_csv',
                'recurrence' => 'daily'
            )
        );

	    if ( Photoslurp_WPML_Helper::wpml_active() ) {
	        $events[] = array(
                'hook'       => 'photoslurp_generate_language_products_csv',
                'recurrence' => 'daily'
            );
        }

		return $events;
	}

	/**
	 * Execution of scheduled events hooks
	 *
	 * @since    1.0.0
	 *
	 * @param    $hook
	 */
	public function execute( $hook ) {
		switch ( $hook ) {
			case 'photoslurp_generate_products_csv':
				$generator = new Photoslurp_Product_CSV();
				$generator->generate();
				break;
            case 'photoslurp_generate_language_products_csv':
                if ( Photoslurp_WPML_Helper::wpml_active() ) {
                    $languages = Photoslurp_WPML_Helper::get_languages();
                    foreach ( $languages as $language_code => $language ) {
                        $generator = new Photoslurp_Product_CSV();
                        $generator->generate($language_code);
                    }
                }
                break;
		}
	}

}
