<?php

/**
 * WooCommerce actions
 *
 * Hook WooCommerce actions
 *
 * @package    Photoslurp
 * @subpackage Photoslurp/public
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Public_Woo_Commerce_Actions {

	/**
	 * Add the actions
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		add_action( 'woocommerce_thankyou', array( $this, 'photoslurp_conversion_tracking' ) );
	}

	/**
	 * Photolsurp conversion tracking
	 *
	 * @since    1.0.0
	 *
	 * @param    int $order_id
	 */
	function photoslurp_conversion_tracking( $order_id ) {

        // Check if order is already tracked to prevent double conversion
	    $tracked = get_post_meta( $order_id, 'photoslurp_conversion_tracked' );
	    if ( intval($tracked) === 1 ) {
	        return;
        }

		$options    = get_option( 'photoslurp_options' );
		$identifier = ! empty( $options['photoslurp_field_products_csv_identifier'] ) ? $options['photoslurp_field_products_csv_identifier'] : 'sku';
		$order      = new WC_Order( $order_id );
		$products   = array();

		foreach ( $order->get_items() as $item ) {
			if ( $item instanceof WC_Order_Item_Product ) {
				$product = $item->get_product();
				if ($product instanceof WC_Product_Variation) {
				    $parent = wc_get_product($product->get_parent_id());
				    $key = ( $identifier === 'sku' ? $parent->get_sku() : $parent->get_id() );
                }else{
					$key = ( $identifier === 'sku' ? $product->get_sku() : $product->get_id() );
                }
				$products[$key] = array(
					'count'    => $item['qty'],
					'price'    => $product->get_sale_price() > 0 ? $product->get_sale_price() : $product->get_price(),
					'currency' => strtolower( $order->get_currency() )
				);
			}
		}

		// Marked order as tracked to prevent double conversion
		update_post_meta( $order_id, 'photoslurp_conversion_tracked', '1' );
		?>
        <!-- Start Photoslurp Embed Code -->
        <script type="text/javascript">
            var photoSlurpTrackingSettings = {
                products: <?php echo json_encode( $products ) ?>
            };
            (function () {
                var d = document,
                    h = d.getElementsByTagName('head')[0],
                    s = d.createElement('script');
                s.type = 'text/javascript';
                s.async = true;
                s.src = '//static.photoslurp.com/widget/v3/tracking_notify.js';
                h.appendChild(s);
            }());
        </script>
        <!-- End Photoslurp Embed Code -->
		<?php
	}

}
