<?php

/**
 * Photoslurp Widget Widget
 *
 * Display a Photoslurp Widget
 *
 * @package    Photoslurp
 * @subpackage Photoslurp/public
 * @author     Tristan Hartman <tristan@hartmanmedia.nl>
 */
class Photoslurp_Widget_Photoslurp_Widget extends WP_Widget {

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct( 'photoslurp_widget', __( 'Photoslurp Widget', 'photoslurp' ), array(
			'description' => __( 'Display a Photoslurp Widget.', 'photoslurp' )
		) );
	}

	/**
	 * Outputs the settings update form
	 *
	 * @since    1.0.0
	 *
	 * @see      WP_Widget->form
	 *
	 * @param    array $instance
	 *
	 * @return   string
	 */
	public function form( $instance ) {
		$post_id = isset( $instance['post_id'] ) ? $instance['post_id'] : 0;
		$options = $this->get_options();
		?>
        <p>
            <label for="<?php echo $this->get_field_id( 'post_id' ); ?>"><?php echo __( 'Widget', 'photoslurp' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'post_id' ) ); ?>" name="<?php echo $this->get_field_name( 'post_id' ); ?>">
				<?php foreach ( $options as $option_key => $option_value ) : ?>
                    <option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $option_key, $post_id ); ?>><?php echo esc_html( $option_value ); ?></option>
				<?php endforeach; ?>
            </select>
        </p>
		<?php
		return '';
	}

	/**
	 * Updates a particular instance of a widget
	 *
	 * @since    1.0.0
	 *
	 * @see      WP_Widget->update
	 *
	 * @param    array $new_instance
	 * @param    array $old_instance
	 *
	 * @return   array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['post_id'] = absint( $new_instance['post_id'] );

		return $instance;
	}

	/**
	 * Output the widget
	 *
	 * @since    1.0.0
	 *
	 * @see      WP_Widget
	 *
	 * @param    array $args
	 * @param    array $instance
	 */
	public function widget( $args, $instance ) {
		if ( empty( $instance['post_id'] ) ) {
			return;
		}

		echo $args['before_widget'];

		$widget = new Photoslurp_Public_Widget( $instance['post_id'] );

		echo $widget->get_output();

		echo $args['after_widget'];
	}

	/**
	 * @since    1.0.0
	 *
	 * @return   array
	 */
	protected function get_options() {
		$options = array();

		$query = new WP_Query( array(
			'post_type'      => 'photoslurp_widget',
			'posts_per_page' => - 1
		) );

		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();

				$options[ get_the_ID() ] = get_the_title();
			}
			wp_reset_postdata();
		}

		return $options;
	}

}
